.. _contact:

Contact
=======

The website `stetl.org <http://stetl.org>`_ is the main entry point for all of Stetl.

All development is done via GitHub: see https://github.com/geopython/stetl.

Contact the main author Just van den Broecke via email at just@justobjects.nl.

Online chat via Gitter: https://gitter.im/geopython/stetl
